{{/*
Expand the name of the chart.
*/}}
{{- define "ipavo.name" -}}
{{- default .Chart.Name .Values.nameOverride | trunc 63 | trimSuffix "-" }}
{{- end }}

{{/*
Create a default fully qualified app name.
We truncate at 63 chars because some Kubernetes name fields are limited to this (by the DNS naming spec).
If release name contains chart name it will be used as a full name.
*/}}
{{- define "ipavo.fullname" -}}
{{- if .Values.fullnameOverride }}
{{- .Values.fullnameOverride | trunc 63 | trimSuffix "-" }}
{{- else }}
{{- $name := default .Chart.Name .Values.nameOverride }}
{{- if contains $name .Release.Name }}
{{- .Release.Name | trunc 63 | trimSuffix "-" }}
{{- else }}
{{- printf "%s-%s" .Release.Name $name | trunc 63 | trimSuffix "-" }}
{{- end }}
{{- end }}
{{- end }}

{{/*
Create chart name and version as used by the chart label.
*/}}
{{- define "ipavo.chart" -}}
{{- printf "%s-%s" .Chart.Name .Chart.Version | replace "+" "_" | trunc 63 | trimSuffix "-" }}
{{- end }}

{{/*
Common labels
*/}}
{{- define "ipavo.labels" -}}
helm.sh/chart: {{ include "ipavo.chart" . }}
{{ include "ipavo.selectorLabels" . }}
{{- if .Chart.AppVersion }}
app.kubernetes.io/version: {{ .Chart.AppVersion | quote }}
{{- end }}
app.kubernetes.io/managed-by: {{ .Release.Service }}
{{- end }}

{{/*
Selector labels
*/}}
{{- define "ipavo.selectorLabels" -}}
app.kubernetes.io/name: {{ include "ipavo.name" . }}
app.kubernetes.io/instance: {{ .Release.Name }}
{{- end }}

{{/*
Create the name of the service account to use
*/}}
{{- define "ipavo.serviceAccountName" -}}
{{- if .Values.server.serviceAccount.create }}
{{- default (include "ipavo.fullname" .) .Values.server.serviceAccount.name }}
{{- else }}
{{- default "default" .Values.server.serviceAccount.name }}
{{- end }}
{{- end }}


{{/*
IPavo server labels
*/}}
{{- define "ipavo.server.labels" -}}
helm.sh/chart: {{ include "ipavo.chart" . }}
{{ include "ipavo.selectorLabels" . }}
{{- if .Chart.AppVersion }}
app.kubernetes.io/version: {{ .Chart.AppVersion | quote }}
{{- end }}
app.kubernetes.io/managed-by: {{ .Release.Service }}
{{- end }}

{{/*
IPavo server selector labels
*/}}
{{- define "ipavo.server.selectorLabels" -}}
app.kubernetes.io/name: {{ include "ipavo.name" . }}
app.kubernetes.io/instance: {{ .Release.Name }}
{{- end }}

{{/*
Create the name of the clusterrole to use
*/}}
{{- define "ipavo.clusterrole" -}}
{{- default (include "ipavo.fullname" .) }}-admin
{{- end }}

{{/*
Create the name of the clusterrolebinding to use
*/}}
{{- define "ipavo.clusterrolebinding" -}}
{{- default (include "ipavo.fullname" .) }}-server
{{- end }}

{{/*
Get external DSN url from dce5-installer database config
*/}}
{{- define "external.database.dsn" -}}
  {{- $db := index . -}}
  {{- $driver := $db.driver | default "mysql" -}}
  {{- if eq $driver "mysql" -}}
    {{- if contains "?" $db.dsn -}}
      {{ $db.dsn }}
    {{- else -}}
      {{ print $db.dsn "?charset=utf8mb4&parseTime=True&loc=Local&multiStatements=true" }}
    {{- end -}}
  {{- else if eq $driver "postgres" -}}
    {{- if contains "sslmode=" $db.dsn -}}
      {{ $db.dsn }}
    {{- else -}}
      {{ print $db.dsn " sslmode=disable" }}
    {{- end -}}
  {{ else }}
    {{ $db.dsn }}
  {{- end -}}
{{- end -}}

{{/*
Get DNS address from internal insight-mysql or external database config
*/}}
{{- define "ipavo.database.dsn" -}}
{{- if .Values.global.storage.builtIn -}}
{{ printf "root:password@tcp(%s-mysql:3306)/ipavo?charset=utf8mb4&parseTime=True&loc=Local&multiStatements=true" .Release.Name }}
{{- else -}}
{{- include "external.database.dsn" (index .Values.global.storage.database 0) -}}
{{- end -}}
{{- end -}}
